@@ -25,10 +25,8 @@ from . import util
 ROOT_DIR = Path(__file__).parent
 SCHEMAS_DIR = ROOT_DIR / "schemas"
 
-METRICS_ID = "moz://mozilla.org/schemas/glean/metrics/1-0-0"
-PINGS_ID = "moz://mozilla.org/schemas/glean/pings/1-0-0"
-
-FILE_TYPES = {METRICS_ID: "metrics", PINGS_ID: "pings"}
+METRICS_ID = "moz://mozilla.org/schemas/glean/metrics/2-0-0"
+PINGS_ID = "moz://mozilla.org/schemas/glean/pings/2-0-0"
 
 
 def _update_validator(validator):
@@ -53,13 +51,21 @@ def _update_validator(validator):
 
 
 def _load_file(
-    filepath: Path,
+    filepath: Path, parser_config: Dict[str, Any]
 ) -> Generator[str, None, Tuple[Dict[str, util.JSONType], Optional[str]]]:
     """
     Load a metrics.yaml or pings.yaml format file.
+
+    If the `filepath` does not exist, raises `FileNotFoundError`, unless
+    `parser_config["allow_missing_files"]` is `True`.
     """
     try:
-        content = util.load_yaml_or_json(filepath, ordered_dict=True)
+        content = util.load_yaml_or_json(filepath)
+    except FileNotFoundError:
+        if not parser_config.get("allow_missing_files", False):
+            raise
+        else:
+            return {}, None
     except Exception as e:
         yield util.format_error(filepath, "", textwrap.fill(str(e)))
         return {}, None
@@ -78,7 +84,14 @@ def _load_file(
     if not isinstance(schema_key, str):
         raise TypeError(f"Invalid schema key {schema_key}")
 
-    filetype = FILE_TYPES.get(schema_key)
+    filetype: Optional[str] = None
+    try:
+        filetype = schema_key.split("/")[-2]
+    except IndexError:
+        filetype = None
+
+    if filetype not in ("metrics", "pings"):
+        filetype = None
 
     for error in validate(content, filepath):
         content = {}
@@ -254,9 +267,14 @@ def _instantiate_pings(
     Load a list of pings.yaml files, convert the JSON information into Ping
     objects.
     """
+    global_no_lint = content.get("no_lint", [])
+    assert isinstance(global_no_lint, list)
+
     for ping_key, ping_val in content.items():
         if ping_key.startswith("$"):
             continue
+        if ping_key == "no_lint":
+            continue
         if not config.get("allow_reserved"):
             if ping_key in RESERVED_PING_NAMES:
                 yield util.format_error(
@@ -269,11 +287,18 @@ def _instantiate_pings(
             raise TypeError(f"Invalid content for ping {ping_key}")
         ping_val["name"] = ping_key
         try:
-            ping_obj = Ping(**ping_val)
+            ping_obj = Ping(
+                defined_in=getattr(ping_val, "defined_in", None),
+                _validated=True,
+                **ping_val,
+            )
         except Exception as e:
             yield util.format_error(filepath, f"On instance '{ping_key}'", str(e))
             continue
 
+        if ping_obj is not None:
+            ping_obj.no_lint = list(set(ping_obj.no_lint + global_no_lint))
+
         already_seen = sources.get(ping_key)
         if already_seen is not None:
             # We've seen this ping name already
@@ -342,6 +367,8 @@ def parse_objects(
           This is useful when you want to retain the original "disabled"
           value from the `metrics.yaml`, rather than having it overridden when
           the metric expires.
+        - `allow_missing_files`: Do not raise a `FileNotFoundError` if any of
+          the input `filepaths` do not exist.
     """
     if config is None:
         config = {}
@@ -350,7 +377,7 @@ def parse_objects(
     sources: Dict[Any, Path] = {}
     filepaths = util.ensure_list(filepaths)
     for filepath in filepaths:
-        content, filetype = yield from _load_file(filepath)
+        content, filetype = yield from _load_file(filepath, config)
         if filetype == "metrics":
             yield from _instantiate_metrics(
                 all_objects, sources, content, filepath, config
