@@ -37,7 +37,7 @@ def test_enforcement():
             type="boolean",
             category="category",
             name="metric",
-            bugs=[42],
+            bugs=["http://bugzilla.mozilla.com/12345"],
             description=42,
             notification_emails=["nobody@example.com"],
             expires="never",
@@ -57,7 +57,7 @@ def test_expires():
             type="boolean",
             category="category",
             name="metric",
-            bugs=[42],
+            bugs=["http://bugzilla.mozilla.com/12345"],
             expires=date,
             notification_emails=["nobody@example.com"],
             description="description...",
@@ -69,7 +69,7 @@ def test_expires():
             type="boolean",
             category="category",
             name="metric",
-            bugs=[42],
+            bugs=["http://bugzilla.mozilla.com/12345"],
             expires="foo",
             notification_emails=["nobody@example.com"],
             description="description...",
@@ -85,7 +85,7 @@ def test_timespan_time_unit():
         type="timespan",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         time_unit="day",
         notification_emails=["nobody@example.com"],
         description="description...",
@@ -99,7 +99,6 @@ def test_timespan_time_unit():
             type="timespan",
             category="category",
             name="metric",
-            bugs=[42],
             time_unit="foo",
             notification_emails=["nobody@example.com"],
             description="description...",
@@ -115,7 +114,7 @@ def test_identifier():
         type="timespan",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         time_unit="day",
         notification_emails=["nobody@example.com"],
         description="description...",
@@ -133,7 +132,7 @@ def test_identifier_glean_category():
         type="timespan",
         category=metrics.Metric.glean_internal_metric_cat,
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         time_unit="day",
         notification_emails=["nobody@example.com"],
         description="description...",
@@ -153,7 +152,7 @@ def test_reserved_extra_keys():
             type="event",
             category="category",
             name="metric",
-            bugs=[42],
+            bugs=["http://bugzilla.mozilla.com/12345"],
             notification_emails=["nobody@example.com"],
             description="description...",
             expires="never",
@@ -164,7 +163,7 @@ def test_reserved_extra_keys():
         type="event",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
@@ -178,7 +177,7 @@ def test_no_unit():
         type="event",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
